@@ -121,6 +121,8 @@ static void STRtree_dealloc(STRtreeObject* self) {
   Py_TYPE(self)->tp_free((PyObject*)self);
 }
 
+void dummy_query_callback(void* item, void* user_data) {}
+
 static PyObject* STRtree_new(PyTypeObject* type, PyObject* args, PyObject* kwds) {
   int node_capacity;
   PyObject* arr;
@@ -197,6 +199,17 @@ static PyObject* STRtree_new(PyTypeObject* type, PyObject* args, PyObject* kwds)
     counter++;
   }
 
+  // A dummy query to trigger the build of the tree (only if the tree is not empty)
+  if (count_indexed > 0) {
+    GEOSGeometry* dummy = create_point(ctx, 0.0, 0.0);
+    if (dummy == NULL) {
+      GEOSSTRtree_destroy_r(ctx, tree);
+      GEOS_FINISH;
+      return NULL;
+    }
+    GEOSSTRtree_query_r(ctx, tree, dummy, dummy_query_callback, NULL);
+  }
+
   STRtreeObject* self = (STRtreeObject*)type->tp_alloc(type, 0);
   if (self == NULL) {
     GEOSSTRtree_destroy_r(ctx, tree);
